Cacher
========================================================

Built-in Cacher
-----------------------------

.. toctree::
    :maxdepth: 2

    base <base>
    MemoryCache <memory_cache>
    DiskCache <disk_cache>

Custom Cacher Relevant
-----------------------------

.. toctree::
    :maxdepth: 2

    Extension hookspec <extension>
    CacherManager <manager>
